nengo\_spa\.vocab
=================

.. automodule:: nengo_spa.vocab

   .. rubric:: Classes

   .. autosummary::

      Vocabulary
      VocabularyMap
      VocabularyMapParam
      VocabularyOrDimParam
